@@ -4,11 +4,8 @@ from volworld_common.api.CA import CA
 
 # ====== A: Attribute ======
 class AA(CA):
-    Request: Final[str] = "req"
-
-    Response: Final[str] = "rsp"
 
     Token: Final[str] = "tk"
 
 
-attList = [AA, CA]
+AAList = [AA, CA]
