@@ -1,7 +1,7 @@
 
 from volworld_aws_api_common.api.enum.HttpStatus import HttpStatus
 from volworld_common.util.id_util import new_rand_test_user_name
-from volworld_aws_api_common.api.AA import AA
+from volworld_aws_api_common.api.AA import AA, AAList
 from volworld_aws_api_common.api.Aws import Aws
 from volworld_aws_api_common.api.url import authUrl
 from volworld_aws_api_common.test.aws.ATestRequest import ATestRequest
@@ -17,7 +17,7 @@ def post__signup(
         authUrl.doSignupUrl, {
             AA.Name: name,
             AA.Password: pw,
-        }, req,
+        }, req, AAList
         )
     return response_to_dict(resp_json, resp)
 
